Module consts

Module consts 

Preset idenitifiers and constants so that the profiler and proc macro agree on their communication protocol.

Constants

IMPORTANCE_LINE_NAME
Identifier for importance in test metadata.
ITER_COUNT_LINE_NAME
Identifier for the iteration count of a test metadata.
ITER_ENV_VAR
The env var in which we pass the iteration count to our tests.
MDATA_LINE_PREF
The prefix printed on all benchmark test metadata lines, to distinguish it from possible output by the test harness itself.
MDATA_VER
The version number for the data returned from the test metadata function. Increment on non-backwards-compatible changes.
NOISE_CUTOFF
How long a test must have run to be assumed to be reliable-ish.
RUNS_DIR
Where to save json run information.
SUF_MDATA
The suffix on an extra function which prints metadata about a test to stdout.
SUF_NORMAL
The suffix on the actual test function.
VERSION_LINE_NAME
Identifier for the test metadata version.
WEIGHT_DEFAULT
The default weight, if none is specified.
WEIGHT_LINE_NAME
Identifier for the weight of a test metadata.