Preset idenitifiers and constants so that the profiler and proc macro agree on their communication protocol.
Constants
- IMPORTANCE_
LINE_ NAME - Identifier for importance in test metadata.
- ITER_
COUNT_ LINE_ NAME - Identifier for the iteration count of a test metadata.
- ITER_
ENV_ VAR - The env var in which we pass the iteration count to our tests.
- MDATA_
LINE_ PREF - The prefix printed on all benchmark test metadata lines, to distinguish it from possible output by the test harness itself.
- MDATA_
VER - The version number for the data returned from the test metadata function. Increment on non-backwards-compatible changes.
- NOISE_
CUTOFF - How long a test must have run to be assumed to be reliable-ish.
- RUNS_
DIR - Where to save json run information.
- SUF_
MDATA - The suffix on an extra function which prints metadata about a test to stdout.
- SUF_
NORMAL - The suffix on the actual test function.
- VERSION_
LINE_ NAME - Identifier for the test metadata version.
- WEIGHT_
DEFAULT - The default weight, if none is specified.
- WEIGHT_
LINE_ NAME - Identifier for the weight of a test metadata.